.. _reference:

Reference
*********

   :Release: |release|
   :Date: |today|

.. toctree::
   :maxdepth: 2

   overview
   classes
   algorithms
   generators
   linalg
   readwrite
   drawing
   history
   credits      
   legal
   citing
